| Title: | Raw and Processed Matrices of the PBMC 3k Dataset |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | Paul Hoffman [aut, cre] (ORCID: <https://orcid.org/0000-0002-7693-8957>), 10x Genomics, Inc. [cph] |
| Maintainer: | Paul Hoffman <[email protected]> |
| License: | CC BY 4.0 |
| Version: | 0.1.0 |
| Built: | 2026-06-02 08:32:25 UTC |
| Source: | https://github.com/mojaveazure/pbmc3k |
2,700 peripheral blood mononuclear cells (PBMC) from 10X genomics; this is
effectively what one would get with
Seurat::Read10X()
pbmc3kpbmc3k
A dgCMatrix with the raw,
unfiltered PBMC 3k counts
https://support.10xgenomics.com/single-cell-gene-expression/datasets/1.1.0/pbmc3k
Log-Normalized PBMC 3k: SingleCellExperiment Edition
pbmc3k.sce.logcountspbmc3k.sce.logcounts
A dgCMatrix with the
log-normalized PBMC 3k counts
There is not a raw, filtered matrix following a Bioconductor workflow
as scuttle does not filter the raw counts matrix in the same way that
SeuratObject::CreateSeuratObject() does
https://support.10xgenomics.com/single-cell-gene-expression/datasets/1.1.0/pbmc3k
Orchestrating Single-Cell Analysis with Bioconductor version 1.8.0
scuttle::perCellQCMetrics(),
scuttle::quickPerCellQC(),
scuttle::perCellQCFilters(),
scuttle::isOutlier()
Log-normalized matrices:
pbmc3k.seurat.norm
Raw PBMC 3k Counts: Seurat Edition
pbmc3k.seurat.countspbmc3k.seurat.counts
A dgCMatrix with the raw,
filtered PBMC 3k counts
https://support.10xgenomics.com/single-cell-gene-expression/datasets/1.1.0/pbmc3k
Seurat PBMC 3k Guided Clustering Tutorial
SeuratObject::CreateSeuratObject(),
SeuratObject::CreateAssayObject()
Seurat-processed matrices:
pbmc3k.seurat.norm
Log-Normalized PBMC 3k: Seurat Edition
pbmc3k.seurat.normpbmc3k.seurat.norm
A dgCMatrix with the
log-normalized PBMC 3k counts
https://support.10xgenomics.com/single-cell-gene-expression/datasets/1.1.0/pbmc3k
Seurat PBMC 3k Guided Clustering Tutorial
Seurat-processed matrices:
pbmc3k.seurat.counts
Log-normalized matrices:
pbmc3k.sce.logcounts